@@ -23,6 +23,7 @@ from __future__ import annotations
 from typing import Optional, Union
 import math
 from kipy.proto.common import types
+from kipy.util import from_mm
 from kipy.wrapper import Wrapper
 
 class Vector2(Wrapper):
@@ -44,6 +45,16 @@ class Vector2(Wrapper):
         proto.y_nm = y_nm
         return cls(proto)
 
+    @classmethod
+    def from_xy_mm(cls, x_mm: int, y_mm: int):
+        """Initialize Vector2 with x and y values in mm
+
+        .. versionadded:: 0.3.0"""
+        proto = types.Vector2()
+        proto.x_nm = from_mm(x_mm)
+        proto.y_nm = from_mm(y_mm)
+        return cls(proto)
+
     @property
     def x(self) -> int:
         return self._proto.x_nm
@@ -96,8 +107,16 @@ class Vector2(Wrapper):
         return math.sqrt(self.x * self.x + self.y * self.y)
 
     def angle(self) -> float:
+        """Returns the angle (direction) of the vector in radians"""
         return math.atan2(self.y, self.x)
 
+    def angle_degrees(self) -> float:
+        """Returns the angle (direction) of the vector in degrees
+
+        .. versionadded:: 0.3.0
+        """
+        return math.degrees(self.angle())
+
 class Vector3D(Wrapper):
     """Wraps a kiapi.common.types.Vector3D"""
     def __init__(self, proto: Optional[types.Vector3D] = None):
@@ -601,14 +620,44 @@ def arc_radius(start: Vector2, mid: Vector2, end: Vector2) -> float:
 
     return (start - center).length()
 
+def normalize_angle_degrees(angle: float) -> float:
+    """Normalizes an angle to fall within the range [0, 360)
+
+    .. versionadded:: 0.3.0"""
+    while angle < 0.0:
+        angle += 360.0
+
+    while angle >= 360.0:
+        angle -= 360.0
+
+    return angle
+
+def normalize_angle_radians(angle: float) -> float:
+    """Normalizes an angle to fall within the range [0, 2*pi)
+
+    .. versionadded:: 0.3.0"""
+    while angle < 0.0:
+        angle += 2 * math.pi
+
+    while angle >= 2 * math.pi:
+        angle -= 2 * math.pi
+
+    return angle
+
 def arc_start_angle(start: Vector2, mid: Vector2, end: Vector2) -> Optional[float]:
+    """Calculates the arc's starting angle in radians, normalized to [0, 2*pi)
+
+    :return: The starting angle of the arc, or None if the arc is degenerate"""
     center = arc_center(start, mid, end)
     if center is None:
         return None
 
-    return (start - center).angle()
+    return normalize_angle_radians((start - center).angle())
 
 def arc_end_angle(start: Vector2, mid: Vector2, end: Vector2) -> Optional[float]:
+    """Calculates the arc's ending angle in radians, normalized to [0, 2*pi)
+
+    :return: The ending angle of the arc, or None if the arc is degenerate"""
     center = arc_center(start, mid, end)
     if center is None:
         return None
@@ -621,7 +670,34 @@ def arc_end_angle(start: Vector2, mid: Vector2, end: Vector2) -> Optional[float]
     if angle == start_angle:
         angle += 2 * math.pi
 
-    while angle < start_angle:
-        angle += 2 * math.pi
+    return normalize_angle_radians(angle)
 
-    return angle
+def arc_start_angle_degrees(start: Vector2, mid: Vector2, end: Vector2) -> Optional[float]:
+    """Calculates the arc's starting angle in degrees, normalized to [0, 360)
+
+    .. versionadded:: 0.3.0
+    """
+    center = arc_center(start, mid, end)
+    if center is None:
+        return None
+
+    return normalize_angle_degrees((start - center).angle_degrees())
+
+def arc_end_angle_degrees(start: Vector2, mid: Vector2, end: Vector2) -> Optional[float]:
+    """Calculates the arc's ending angle in degrees, normalized to [0, 360)
+
+    .. versionadded:: 0.3.0
+    """
+    center = arc_center(start, mid, end)
+    if center is None:
+        return None
+
+    angle = (end - center).angle_degrees()
+
+    start_angle = arc_start_angle(start, mid, end)
+    assert(start_angle is not None)
+
+    if angle == start_angle:
+        angle += 360
+
+    return normalize_angle_degrees(angle)
